<template>
  <div class="ClusterList">
    <div v-if="showCluster">
      <div class="title" v-if="listType == 'cluster'">集群列表</div>
      <div class="back" v-else>
        <span class="iconfont" @click="back">&#xe62c;</span>设备列表
      </div>
      <div class="List">
        <ClusterCard
          v-for="(item, index) in listData"
          :key="index"
          :info="item"
          @showDetail="showList(item)"
        ></ClusterCard>

        <div
          class="ClusterCard"
          v-for="i in emptylength"
          :key="'empty' + i"
        ></div>
      </div>
      <el-pagination
        @current-change="refrash"
        @size-change="handleSizeChange"
        :small="true"
        :current-page="page"
        :page-size="size"
        layout="total, sizes, prev, pager, next, jumper"
        :page-sizes="[5, 10, 15, 20, 25]"
        :total="total"
        background
      ></el-pagination>
    </div>

    <EquipmentForm
      :name="activeName"
      :id="devId"
      v-else
      @hiddenList="hiddenList"
    ></EquipmentForm>
  </div>
</template>

<script>
import ClusterCard from "./ClusterCard";
import EquipmentForm from "./EquipmentForm";
export default {
  props: {
    list: {},
    listType: {},
  },
  created() {},
  mounted() {},
  components: {
    ClusterCard,
    EquipmentForm,
  },
  data() {
    return {
      showCluster: true,
      emptylength: 0,
      page: 1,
      size: 10,
      devId: "",
      activeName: "",
    };
  },
  methods: {
    handleSizeChange(size) {
      this.size = size;
    },
    refrash(page) {
      this.page = page;
    },
    showList(dev) {
      if (dev.type == 1) {
        this.$emit("chooseCluster", dev.id);
      } else {
        this.$emit("chooseDevice", dev.id);
        this.devId = dev.id;
        this.activeName = dev.name;
        this.showCluster = false;
      }
    },
    hiddenList() {
      this.showCluster = true;
    },
    back() {
      this.$emit("back");
    },
  },
  computed: {
    listData() {
      let arr = [];
      arr = this.list.slice((this.page - 1) * this.size, this.page * this.size);
      return arr;
    },
    total() {
      return this.list.length;
    },
  },
};
</script>

<style lang="scss" scoped>
.ClusterList {
  box-sizing: border-box;
  margin-bottom: 60px;
  padding: 20px;
  background-color: #fff;
  .title {
    margin-bottom: 30px;
    padding-left: 10px;
    height: 20px;
    line-height: 20px;
    border-left: 4px solid #0065ff;
    font-size: 16px;
    font-weight: 700;
  }
  .back {
    margin-bottom: 30px;
    font-size: 18px;
    font-weight: 700;
    span {
      margin-right: 10px;
      cursor: pointer;
    }
  }

  .List {
    display: flex;
    flex-wrap: wrap;

    .ClusterCard {
      width: 434px;
      margin-right: 24px;
      margin-bottom: 24px;
      padding: 20px;
    }
  }

  .el-pagination ::v-deep {
    margin-top: 30px;
    text-align: right;
    height: 24px;
    .el-pagination__sizes {
      margin-right: 0;
    }

    button {
      margin: 0;
      background-color: #fff;
      border: 1px solid #c0c5cc;
      border-radius: 2px;
    }

    .number {
      background-color: #fff;

      &:not(.disabled):hover {
        color: #0065ff;
      }

      &:not(.disabled).active {
        background-color: #0065ff;
        color: #fff;
      }
    }

    .el-input .el-input__inner {
      padding-left: 0;
      height: 22px;
      line-height: 22px;

      &:hover,
      &:focus {
        border-color: #0065ff;
      }
    }

    .el-input__suffix {
      height: 120%;
      top: -1px;
    }

    .el-pagination__total {
      font-weight: 700;
    }
  }
}
</style>